@@ -106,9 +106,11 @@ def contact_birthday_to_airsync(ctx):
     s = xml2util.GetNodeValue(transform_ctx.current())
     return "%s-%s-%sT00:00:00.000Z" % (s[0:4], s[4:6], s[6:8])
 
+# OS0.2x has an inconsistency in date representation
+
 def contact_anniversary_from_airsync(ctx):
     parser_ctx, transform_ctx = xml2util.ExtractContexts(ctx)
-    return xml2util.GetNodeValue(transform_ctx.current()).split("T")[0]
+    return xml2util.GetNodeValue(transform_ctx.current()).split("T")[0].replace("-", "")
 
 def contact_birthday_from_airsync(ctx):
     parser_ctx, transform_ctx = xml2util.ExtractContexts(ctx)
@@ -497,9 +499,10 @@ def task_start_date_to_airsync(ctx):
     localDate,utcDate = tzconv.ConvertDateNodeToUTC(transform_ctx.current())
     dst_node = transform_ctx.insertNode()
     n=dst_node.newChild(None,"StartDate",localDate.strftime(DATE_FORMAT_TASKLOCAL))
-    n.setNs(None)
+    nsNew=n.newNs("http://synce.org.formats/airsync_wm5/tasks","T")
+    n.setNs(nsNew)
     n=dst_node.newChild(None,"UtcStartDate",utcDate.strftime(DATE_FORMAT_TASK))
-    n.setNs(None)
+    n.setNs(nsNew)
     return ""
 
 def task_due_date_to_airsync(ctx):
@@ -507,9 +510,10 @@ def task_due_date_to_airsync(ctx):
     localDate,utcDate = tzconv.ConvertDateNodeToUTC(transform_ctx.current())
     dst_node = transform_ctx.insertNode()
     n=dst_node.newChild(None,"DueDate",localDate.strftime(DATE_FORMAT_TASKLOCAL))
-    n.setNs(None)
+    nsNew=n.newNs("http://synce.org/formats/airsync_wm5/tasks","T")
+    n.setNs(nsNew)
     n=dst_node.newChild(None,"UtcDueDate",utcDate.strftime(DATE_FORMAT_TASK))
-    n.setNs(None)
+    n.setNs(nsNew)
     return ""
 
 def task_start_date_from_airsync(ctx):
