@@ -101,6 +101,7 @@ class SyncEngine(dbus.service.Object):
 		self.device = None
 		self.deviceName = ""
 		self.devicePath = ""
+		self.partnerships = None
 
 		# Attempt to connect to a running odccm. If a running odccm is not available, we can wait for
 		# it to become available.
@@ -118,6 +119,22 @@ class SyncEngine(dbus.service.Object):
 		except:
 			self.isOdccmRunning = False
 
+
+		# Attempt to connect to Hal manager
+
+		try:
+			self.hal_manager = dbus.Interface(dbus.SystemBus().get_object(DBUS_HAL_BUSNAME, DBUS_HAL_MANAGER_OBJPATH), DBUS_HAL_MANAGER_IFACE)
+			self.hal_manager.connect_to_signal("DeviceAdded", self._CBHalDeviceConnected)
+			self.hal_manager.connect_to_signal("DeviceRemoved", self._CBHalDeviceDisconnected)
+
+			obj_paths = self.hal_manager.FindDeviceStringMatch("pda.platform", "pocketpc")
+
+			if len(obj_paths) > 0:
+				self.logger.info("__init__: connected device found")
+				self._CBHalDeviceConnected(obj_paths[0])
+		except Exception, inst:
+			self.logger.info("__init__: exception %s", inst)
+
 	#
 	# _CBODCCMStatusChanged
 	#
@@ -217,6 +234,67 @@ class SyncEngine(dbus.service.Object):
 		else:
 			self.logger.info("_CBDeviceDisconnected: ignoring non-live device detach")
 
+	#
+	# _CBHalDeviceConnected
+	#
+	# INTERNAL
+	#
+	# Callback triggered when a device is connected through Hal.
+	#
+
+	def _CBHalDeviceConnected(self, obj_path):
+	 
+		if self.isOdccmRunning:
+			return
+
+		# check if it's a pocketpc
+		deviceObject = dbus.SystemBus().get_object(DBUS_HAL_BUSNAME, obj_path)
+		device = dbus.Interface(deviceObject,DBUS_HAL_DEVICE_IFACE)
+
+		if not device.PropertyExists("pda.pocketpc.name"):
+			device = None
+			return
+
+		self.logger.info("_CBHalDeviceConnected: device connected at udi %s", obj_path)
+
+		if self.isConnected == False:
+			self.device = device
+
+			# update config from file
+	
+			self.config.UpdateConfig()
+
+			self.device.connect_to_signal("PropertyModified", self._CBHalDeviceAuthStateChanged)
+			self.deviceName = self.device.GetPropertyString("pda.pocketpc.name")
+			self.logger.info(" device %s connected" % self.deviceName)
+			self.devicePath = obj_path
+			if self._ProcessAuth():
+				self.OnConnect()
+		else:
+			if obj_path == self.devicePath:
+				self.logger.info("_CBHalDeviceConnected: device already connected")
+			else:
+				self.logger.info("_CBHalDeviceConnected: other device already connected - ignoring new device")
+
+	#
+	# _CBHalDeviceDisconnected
+	#
+	# INTERNAL
+	#
+	# Callback triggered when a device is disconnected through Hal
+	#
+
+	def _CBHalDeviceDisconnected(self, obj_path):
+
+		if self.isOdccmRunning:
+			return
+
+		if self.devicePath == obj_path:
+			self.logger.info("_CBHalDeviceDisconnected: device disconnected from udi %s", obj_path)
+			self.device=None
+			self.deviceName = ""
+			self.OnDisconnect()
+
 	#
 	# _CheckDeviceConnected
 	#
@@ -241,7 +319,27 @@ class SyncEngine(dbus.service.Object):
 	def _CBDeviceAuthStateChanged(self,added,removed):
 			
 		self.logger.info("_CBDeviceAuthStateChanged: device authorization state changed: reauthorizing")
-		self._ProcessAuth()
+		if not self.isConnected:
+			if self._ProcessAuth():
+				self.OnConnect()
+
+	#
+	# _CBHalDeviceAuthStateChanged
+	#
+	# INTERNAL
+	#
+	# Callback triggered when a Hal device property is changed, for checking authorization state changes
+	#
+
+	def _CBHalDeviceAuthStateChanged(self,num_changes,properties):
+			
+		for property in properties:
+			property_name, added, removed = property
+			if property_name == "pda.pocketpc.password":
+				self.logger.info("_CBHalDeviceAuthStateChanged: device authorization state changed: reauthorizing")
+				if not self.isConnected:
+					if self._ProcessAuth():
+						self.OnConnect()
 
 	#
 	# _CheckAndGetValidPartnership
@@ -276,11 +374,18 @@ class SyncEngine(dbus.service.Object):
 			# if we suddenly need auth, first shut down all threads if they
 			# are running
 		
-			if self.partnerships != None:
+			if self.PshipManager.GetCurrentPartnership() != None:
 				self.OnDisconnect()
-			
-			if auth.Authorize(self.devicePath,self.device,self.config.config_Global):
+
+			result = auth.Authorize(self.devicePath,self.device,self.config.config_Global)
+			if result == 0:
+				self.logger.info("Authorization pending")
+				rc = False
+			elif result == 1:
 				self.logger.info("Authorization successful - reconnecting to device")
+			elif result == 2:
+				self.logger.info("Authorization pending - waiting for password on device")
+				rc = False
 			else:
 				self.logger.info("Failed to authorize - disconnect and reconnect device to try again")
 				rc = False
@@ -300,6 +405,7 @@ class SyncEngine(dbus.service.Object):
 	def _ResetCurrentState(self):
 			
 		autosync_triggered=False
+		self.syncing.unlock()
 
 	# 
 	# OnConnect
@@ -380,6 +486,7 @@ class SyncEngine(dbus.service.Object):
 		#### we MUST change this to bind to the device address only!
 	
 		if mh == "1" and gh == 1:
+			self.logger.debug("StartSessions: DTPT starting")
 			self.dtptsession = dtptserver.DTPTServer("0.0.0.0")
 			self.dtptsession.start()
 		else:
